@@ -1,11 +1,9 @@
 from django.contrib import admin
-from appcms.models import *
+from appcms.models import Placeholder
 from cms.admin.placeholderadmin import PlaceholderAdmin
 
 
 class AppCmsPlaceholderAdmin(PlaceholderAdmin):
-
-    def placeholder_plugin_filter(self, request, queryset):
-        return queryset.filter(language=request.LANGUAGE_CODE)
+    pass
 
 admin.site.register(Placeholder, AppCmsPlaceholderAdmin)
